@@ -63,7 +63,7 @@ def inference(img_path,ocr,cvdnn_path):
                 case=np.argmax(scores)
                 scores=[scores[case]]
                 txts=[txts[case]]
-            if(re.search(regex, txts[0]) and float(txts[0])<20.0 and float(txts[0])>15.0):
+            if(re.search(regex, txts[0]) and float(txts[0])<20.0 and float(txts[0])>=15.0):
                     return str(txts[0]),float(scores[0])
             else:
                     return "999",float(0.0)
